@@ -176,8 +176,6 @@ int docmd_comb(arg_struct *arg) {
         x = y - x;
     #ifdef BCD_MATH
         s = x == 0 ? 1 : pow(10, 1 + floor(log10(x)));
-    #elif ANDROID
-        s = x == 0 ? 1 : pow(2, 1 + floor(log(x) / log(phloat(2))));
     #else
         s = x == 0 ? 1 : pow(2, 1 + floor(log2(x)));
     #endif
@@ -427,9 +425,6 @@ int docmd_input(arg_struct *arg) {
 
 int view_helper(arg_struct *arg, bool print) {
     int err;
-    char buf[22];
-    int bufptr = 0, part2;
-    vartype *v;
     if (arg->type == ARGTYPE_IND_NUM
             || arg->type == ARGTYPE_IND_STK
             || arg->type == ARGTYPE_IND_STR) {
@@ -437,6 +432,13 @@ int view_helper(arg_struct *arg, bool print) {
         if (err != ERR_NONE)
             return err;
     }
+    vartype *v;
+    err = generic_rcl(arg, &v);
+    if (err != ERR_NONE)
+        return err;
+
+    char buf[64];
+    int bufptr = 0;
     switch (arg->type) {
         case ARGTYPE_NUM: {
             int num = arg->val.num;
@@ -455,27 +457,43 @@ int view_helper(arg_struct *arg, bool print) {
             break;
     }
     char2buf(buf, 22, &bufptr, '=');
-    part2 = bufptr;
-    err = generic_rcl(arg, &v);
-    if (err != ERR_NONE)
-        return err;
+    int part2 = bufptr;
+
     bufptr += vartype2string(v, buf + bufptr, 22 - bufptr);
-    free_vartype(v);
     clear_row(0);
     draw_string(0, 0, buf, bufptr);
     flush_display();
     flags.f.message = 1;
     flags.f.two_line_message = 0;
 
+    err = ERR_NONE;
     if (print && (flags.f.printer_enable || !program_running())) {
         if (flags.f.printer_exists) {
-            shell_annunciators(-1, -1, 1, -1, -1, -1);
-            print_wide(buf, part2, buf + part2, bufptr - part2);
-            shell_annunciators(-1, -1, 0, -1, -1, -1);
+            set_annunciators(-1, -1, 1, -1, -1, -1);
+            bufptr = part2;
+            char *sbuf = NULL;
+            char *pbuf = buf;
+            int slen = 64;
+            if (v->type == TYPE_STRING) {
+                vartype_string *s = (vartype_string *) v;
+                slen = bufptr + s->length + 2;
+                sbuf = (char *) malloc(slen);
+                if (sbuf == NULL) {
+                    slen = 64;
+                } else {
+                    memcpy(sbuf, buf, bufptr);
+                    pbuf = sbuf;
+                }
+            }
+            bufptr += vartype2string(v, pbuf + bufptr, slen - bufptr);
+            print_lines(pbuf, bufptr, true);
+            free(sbuf);
+            set_annunciators(-1, -1, 0, -1, -1, -1);
         } else
-            return ERR_STOP;
+            err = ERR_STOP;
     }
-    return ERR_NONE;
+    free_vartype(v);
+    return err;
 }
 
 int docmd_view(arg_struct *arg) {
@@ -1071,7 +1089,7 @@ int docmd_prsigma(arg_struct *arg) {
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
 
-    shell_annunciators(-1, -1, 1, -1, -1, -1);
+    set_annunciators(-1, -1, 1, -1, -1, -1);
     print_text(NULL, 0, true);
     for (i = 0; i < nr; i++) {
         int4 j = i + mode_sigma_reg;
@@ -1094,7 +1112,7 @@ int docmd_prsigma(arg_struct *arg) {
             print_wide(sigma_labels[i].text, sigma_labels[i].length, buf, bufptr);
         }
     }
-    shell_annunciators(-1, -1, 0, -1, -1, -1);
+    set_annunciators(-1, -1, 0, -1, -1, -1);
     return ERR_NONE;
 }
 
@@ -1142,14 +1160,14 @@ int docmd_prv(arg_struct *arg) {
         if (!flags.f.printer_exists)
             return ERR_PRINTING_IS_DISABLED;
 
-        shell_annunciators(-1, -1, 1, -1, -1, -1);
+        set_annunciators(-1, -1, 1, -1, -1, -1);
         string2buf(lbuf, 8, &llen, arg->val.text, arg->length);
         char2buf(lbuf, 8, &llen, '=');
         if (v->type == TYPE_STRING) {
             vartype_string *s = (vartype_string *) v;
             char *sbuf = (char *) malloc(s->length + 2);
             if (sbuf == NULL) {
-                shell_annunciators(-1, -1, 0, -1, -1, -1);
+                set_annunciators(-1, -1, 0, -1, -1, -1);
                 return ERR_INSUFFICIENT_MEMORY;
             }
             sbuf[0] = '"';
@@ -1173,7 +1191,7 @@ int docmd_prv(arg_struct *arg) {
             mode_stoppable = true;
             return ERR_INTERRUPTIBLE;
         } else {
-            shell_annunciators(-1, -1, 0, -1, -1, -1);
+            set_annunciators(-1, -1, 0, -1, -1, -1);
             return ERR_NONE;
         }
     }
@@ -1185,7 +1203,7 @@ static int prv_worker(bool interrupted) {
     int4 i, j, sz;
 
     if (interrupted) {
-        shell_annunciators(-1, -1, 0, -1, -1, -1);
+        set_annunciators(-1, -1, 0, -1, -1, -1);
         return ERR_STOP;
     }
 
@@ -1276,7 +1294,7 @@ static int prv_worker(bool interrupted) {
     if (++prv_index < sz)
         return ERR_INTERRUPTIBLE;
     else {
-        shell_annunciators(-1, -1, 0, -1, -1, -1);
+        set_annunciators(-1, -1, 0, -1, -1, -1);
         return ERR_NONE;
     }
 }
@@ -1289,7 +1307,7 @@ int docmd_prreg(arg_struct *arg) {
         return ERR_NONE;
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
-    shell_annunciators(-1, -1, 1, -1, -1, -1);
+    set_annunciators(-1, -1, 1, -1, -1, -1);
     print_text(NULL, 0, true);
     prv_var = regs;
     prv_prreg = true;
@@ -1307,7 +1325,7 @@ int docmd_prstk(arg_struct *arg) {
         return ERR_NONE;
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
-    shell_annunciators(-1, -1, 1, -1, -1, -1);
+    set_annunciators(-1, -1, 1, -1, -1, -1);
     if (arg != NULL)
         print_text(NULL, 0, true);
     if (flags.f.big_stack) {
@@ -1359,7 +1377,7 @@ int docmd_prstk(arg_struct *arg) {
             }
         }
     }
-    shell_annunciators(-1, -1, 0, -1, -1, -1);
+    set_annunciators(-1, -1, 0, -1, -1, -1);
     return ERR_NONE;
 }
 
@@ -1368,7 +1386,7 @@ static int pra_helper(bool trace, const char *text, int length) {
         return ERR_NONE;
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
-    shell_annunciators(-1, -1, 1, -1, -1, -1);
+    set_annunciators(-1, -1, 1, -1, -1, -1);
     if (length == 0)
         print_text(NULL, 0, true);
     else {
@@ -1389,7 +1407,7 @@ static int pra_helper(bool trace, const char *text, int length) {
             print_text(text + line_start,
                        length - line_start, true);
     }
-    shell_annunciators(-1, -1, 0, -1, -1, -1);
+    set_annunciators(-1, -1, 0, -1, -1, -1);
     return ERR_NONE;
 }
 
@@ -1417,12 +1435,12 @@ int docmd_prx(arg_struct *arg) {
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
     else {
-        shell_annunciators(-1, -1, 1, -1, -1, -1);
+        set_annunciators(-1, -1, 1, -1, -1, -1);
         if (stack[sp]->type == TYPE_STRING) {
             vartype_string *s = (vartype_string *) stack[sp];
             char *lbuf = (char *) malloc(s->length + 2);
             if (lbuf == NULL) {
-                shell_annunciators(-1, -1, 0, -1, -1, -1);
+                set_annunciators(-1, -1, 0, -1, -1, -1);
                 return ERR_INSUFFICIENT_MEMORY;
             }
             lbuf[0] = '"';
@@ -1457,7 +1475,7 @@ int docmd_prx(arg_struct *arg) {
             mode_stoppable = true;
             return ERR_INTERRUPTIBLE;
         } else {
-            shell_annunciators(-1, -1, 0, -1, -1, -1);
+            set_annunciators(-1, -1, 0, -1, -1, -1);
             return ERR_NONE;
         }
     }
@@ -1473,7 +1491,7 @@ int docmd_prusr(arg_struct *arg) {
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
     else {
-        shell_annunciators(-1, -1, 1, -1, -1, -1);
+        set_annunciators(-1, -1, 1, -1, -1, -1);
         print_text(NULL, 0, true);
         prusr_state = 0;
         prusr_index = vars_count - 1;
@@ -1485,7 +1503,7 @@ int docmd_prusr(arg_struct *arg) {
 
 static int prusr_worker(bool interrupted) {
     if (interrupted) {
-        shell_annunciators(-1, -1, 0, -1, -1, -1);
+        set_annunciators(-1, -1, 0, -1, -1, -1);
         return ERR_STOP;
     }
 
@@ -1529,7 +1547,7 @@ static int prusr_worker(bool interrupted) {
         state1:
         len = 0;
         if (prusr_index >= labels_count) {
-            shell_annunciators(-1, -1, 0, -1, -1, -1);
+            set_annunciators(-1, -1, 0, -1, -1, -1);
             return ERR_NONE;
         }
         if (labels[prusr_index].length == 0) {
@@ -1562,9 +1580,9 @@ int docmd_list(arg_struct *arg) {
 int docmd_adv(arg_struct *arg) {
     if (flags.f.printer_exists
             && (flags.f.printer_enable || !program_running())) {
-        shell_annunciators(-1, -1, 1, -1, -1, -1);
+        set_annunciators(-1, -1, 1, -1, -1, -1);
         print_text(NULL, 0, true);
-        shell_annunciators(-1, -1, 0, -1, -1, -1);
+        set_annunciators(-1, -1, 0, -1, -1, -1);
     }
     return ERR_NONE;
 }
@@ -1575,9 +1593,9 @@ int docmd_prlcd(arg_struct *arg) {
     if (!flags.f.printer_exists)
         return ERR_PRINTING_IS_DISABLED;
     else {
-        shell_annunciators(-1, -1, 1, -1, -1, -1);
+        set_annunciators(-1, -1, 1, -1, -1, -1);
         print_display();
-        shell_annunciators(-1, -1, 0, -1, -1, -1);
+        set_annunciators(-1, -1, 0, -1, -1, -1);
         return ERR_NONE;
     }
 }
@@ -1924,6 +1942,7 @@ int docmd_off(arg_struct *arg) {
     if (program_running() && no_keystrokes_yet)
         return ERR_SUSPICIOUS_OFF;
     set_running(false);
+    quitting = true;
     shell_powerdown();
     return ERR_NONE;
 }
