@@ -46,11 +46,6 @@ int docmd_fptest(arg_struct *arg);
 int docmd_lsto(arg_struct *arg);
 int docmd_lasto(arg_struct *arg);
 int docmd_lxasto(arg_struct *arg);
-int docmd_wsize(arg_struct *arg);
-int docmd_wsize_t(arg_struct *arg);
-int docmd_bsigned(arg_struct *arg);
-int docmd_bwrap(arg_struct *arg);
-int docmd_breset(arg_struct *arg);
 
 int docmd_nop(arg_struct *arg);
 int docmd_fma(arg_struct *arg);
@@ -72,6 +67,8 @@ int docmd_rcomplx(arg_struct *arg);
 int docmd_pcomplx(arg_struct *arg);
 int docmd_caps(arg_struct *arg);
 int docmd_mixed(arg_struct *arg);
+int docmd_static(arg_struct *arg);
+int docmd_dynamic(arg_struct *arg);
 int docmd_skip(arg_struct *arg);
 int docmd_cpxmat_t(arg_struct *arg);
 int docmd_type_t(arg_struct *arg);
