@@ -34,7 +34,7 @@ void fly_goose();
 void squeak();
 void tone(int n);
 void draw_char(int x, int y, char c);
-const char *get_char(char c);
+const unsigned char *get_char(char c);
 void draw_string(int x, int y, const char *s, int length);
 int special_menu_key(int which);
 void clear_row(int row);
