@@ -399,17 +399,61 @@ const command_spec cmd_array[] =
     { /* LSTO */        docmd_lsto,        "LSTO",                0x00, 0xc7, 0xf2, 0xed,  4, ARG_NAMED,  1, ALLT },
     { /* SST_UP */      NULL,              "SST^",                0x40, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
     { /* SST_RT */      NULL,              "SST\17",              0x40, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
-    { /* WSIZE */       docmd_wsize,       "WSIZE",               0x00, 0x00, 0xa7, 0xd3,  5, ARG_NONE,   1, 0x01 },
-    { /* WSIZE_T */     docmd_wsize_t,     "WS\311Z\305?",        0x00, 0x00, 0xa7, 0xd4,  6, ARG_NONE,   0, NA_T },
     { /* YMD */         docmd_ymd,         "YMD",                 0x00, 0x00, 0xa7, 0xd5,  3, ARG_NONE,   0, NA_T },
-    { /* BSIGNED */     docmd_bsigned,     "BS\311GN\305\304",    0x00, 0x00, 0xa7, 0xd6,  7, ARG_NONE,   0, NA_T },
-    { /* BWRAP */       docmd_bwrap,       "BWR\301P",            0x00, 0x00, 0xa7, 0xd7,  5, ARG_NONE,   0, NA_T },
-    { /* BRESET */      docmd_breset,      "BR\305S\305T",        0x00, 0x00, 0xa7, 0xd8,  6, ARG_NONE,   0, NA_T },
     { /* GETKEY1 */     docmd_getkey1,     "G\305TK\305\3311",    0x00, 0x00, 0xa7, 0xd9,  7, ARG_NONE,   0, NA_T },
     { /* GETKEYA */     docmd_getkeya,     "G\305TK\305\331A",    0x00, 0x00, 0xa6, 0xee,  7, ARG_NONE,   0, NA_T },
     { /* LASTO */       docmd_lasto,       "LASTO",               0x00, 0xf5, 0xf2, 0xc8,  5, ARG_NAMED,  0, NA_T },
     { /* LCLV */        docmd_lclv,        "LCLV",                0x00, 0x71, 0xf2, 0x64,  4, ARG_NAMED,  0, NA_T },
 
+    /* BASE enhancements */
+    { /* SL */          docmd_sl,          "SL",                  0x00, 0x00, 0xa7, 0xdc,  2, ARG_NONE,   1, 0x01 },
+    { /* SR */          docmd_sr,          "SR",                  0x00, 0x00, 0xa7, 0xdd,  2, ARG_NONE,   1, 0x01 },
+    { /* ASR */         docmd_asr,         "ASR",                 0x00, 0x00, 0xa7, 0x2c,  3, ARG_NONE,   1, 0x01 },
+    { /* SLN */         docmd_sln,         "SLN",                 0x00, 0x00, 0xa7, 0x73,  3, ARG_NONE,   2, 0x01 },
+    { /* SRN */         docmd_srn,         "SRN",                 0x00, 0x00, 0xa7, 0x74,  3, ARG_NONE,   2, 0x01 },
+    { /* ASRN */        docmd_asrn,        "ASRN",                0x00, 0x00, 0xa7, 0x75,  4, ARG_NONE,   2, 0x01 },
+    { /* LJ */          docmd_lj,          "LJ",                  0x00, 0x00, 0xa7, 0x2b,  2, ARG_NONE,   1, 0x01 },
+    { /* RJ */          docmd_rj,          "RJ",                  0x00, 0x00, 0xa7, 0x72,  2, ARG_NONE,   1, 0x01 },
+    { /* RL */          docmd_rl,          "RL",                  0x00, 0x00, 0xa7, 0xe0,  2, ARG_NONE,   1, 0x01 },
+    { /* RR */          docmd_rr,          "RR",                  0x00, 0x00, 0xa7, 0xfa,  2, ARG_NONE,   1, 0x01 },
+    { /* RLC */         docmd_rlc,         "RLC",                 0x00, 0x00, 0xa7, 0xfb,  3, ARG_NONE,   1, 0x01 },
+    { /* RRC */         docmd_rrc,         "RRC",                 0x00, 0x00, 0xa7, 0x2a,  3, ARG_NONE,   1, 0x01 },
+    { /* RLN */         docmd_rln,         "RLN",                 0x00, 0x00, 0xa7, 0x2d,  3, ARG_NONE,   2, 0x01 },
+    { /* RRN */         docmd_rrn,         "RRN",                 0x00, 0x00, 0xa7, 0x2e,  3, ARG_NONE,   2, 0x01 },
+    { /* RLCN */        docmd_rlcn,        "RLCN",                0x00, 0x00, 0xa7, 0x2f,  4, ARG_NONE,   2, 0x01 },
+    { /* RRCN */        docmd_rrcn,        "RRCN",                0x00, 0x00, 0xa7, 0x30,  4, ARG_NONE,   2, 0x01 },
+    { /* SB */          docmd_sb,          "SB",                  0x00, 0x00, 0xa7, 0x31,  2, ARG_NONE,   2, 0x01 },
+    { /* CB */          docmd_cb,          "CB",                  0x00, 0x00, 0xa7, 0x32,  2, ARG_NONE,   2, 0x01 },
+    { /* B_T */         docmd_b_t,         "B?",                  0x00, 0x00, 0xa7, 0x33,  2, ARG_NONE,   2, 0x01 },
+    { /* NUM_B */       docmd_num_b,       "#B",                  0x00, 0x00, 0xa7, 0x34,  2, ARG_NONE,   1, 0x01 },
+    { /* MASKL */       docmd_maskl,       "M\301SKL",            0x00, 0x00, 0xa7, 0x35,  5, ARG_NONE,   1, 0x01 },
+    { /* MASKR */       docmd_maskr,       "M\301SKR",            0x00, 0x00, 0xa7, 0x36,  5, ARG_NONE,   1, 0x01 },
+    { /* SC */          docmd_sc,          "SC",                  0x00, 0x00, 0xa7, 0x37,  2, ARG_NONE,   0, NA_T },
+    { /* CC */          docmd_cc,          "CC",                  0x00, 0x00, 0xa7, 0x38,  2, ARG_NONE,   0, NA_T },
+    { /* C_T */         docmd_c_t,         "C?",                  0x00, 0x00, 0xa7, 0x39,  2, ARG_NONE,   0, NA_T },
+    { /* N_TO_BS */     docmd_n_to_bs,     "N\17BS",              0x00, 0x00, 0xa7, 0x3f,  4, ARG_NONE,   1, 0x01 },
+    { /* N_TO_BD */     docmd_n_to_bd,     "N\17BD",              0x00, 0x00, 0xa7, 0x67,  4, ARG_NONE,   1, 0x01 },
+    { /* N_TO_BQ */     docmd_n_to_bq,     "N\17BQ",              0x00, 0x00, 0xa7, 0x68,  4, ARG_NONE,   1, 0x01 },
+    { /* N_TO_DS */     docmd_n_to_ds,     "N\17DS",              0x00, 0x00, 0xa7, 0x69,  4, ARG_NONE,   1, 0x01 },
+    { /* N_TO_DD */     docmd_n_to_dd,     "N\17DD",              0x00, 0x00, 0xa7, 0x6a,  4, ARG_NONE,   1, 0x01 },
+    { /* N_TO_DQ */     docmd_n_to_dq,     "N\17DQ",              0x00, 0x00, 0xa7, 0x6b,  4, ARG_NONE,   1, 0x01 },
+    { /* BS_TO_N */     docmd_bs_to_n,     "BS\17N",              0x00, 0x00, 0xa7, 0x6c,  4, ARG_NONE,   1, 0x11 },
+    { /* BD_TO_N */     docmd_bd_to_n,     "BD\17N",              0x00, 0x00, 0xa7, 0x6d,  4, ARG_NONE,   1, 0x11 },
+    { /* BQ_TO_N */     docmd_bq_to_n,     "BQ\17N",              0x00, 0x00, 0xa7, 0x6e,  4, ARG_NONE,   1, 0x11 },
+    { /* DS_TO_N */     docmd_ds_to_n,     "DS\17N",              0x00, 0x00, 0xa7, 0x6f,  4, ARG_NONE,   1, 0x11 },
+    { /* DD_TO_N */     docmd_dd_to_n,     "DD\17N",              0x00, 0x00, 0xa7, 0x70,  4, ARG_NONE,   1, 0x11 },
+    { /* DQ_TO_N */     docmd_dq_to_n,     "DQ\17N",              0x00, 0x00, 0xa7, 0x71,  4, ARG_NONE,   1, 0x11 },
+    { /* WSIZE */       docmd_wsize,       "WSIZE",               0x00, 0x00, 0xa7, 0xd3,  5, ARG_NONE,   1, 0x01 },
+    { /* WSIZE_T */     docmd_wsize_t,     "WS\311Z\305?",        0x00, 0x00, 0xa7, 0xd4,  6, ARG_NONE,   0, NA_T },
+    { /* BSIGNED */     docmd_bsigned,     "BS\311GN\305\304",    0x00, 0x00, 0xa7, 0xd6,  7, ARG_NONE,   0, NA_T },
+    { /* BWRAP */       docmd_bwrap,       "BWR\301P",            0x00, 0x00, 0xa7, 0xd7,  5, ARG_NONE,   0, NA_T },
+    { /* BRESET */      docmd_breset,      "BR\305S\305T",        0x00, 0x00, 0xa7, 0xd8,  6, ARG_NONE,   0, NA_T },
+    { /* DECINT */      docmd_decint,      "DECINT",              0x00, 0x00, 0xa7, 0x3a,  6, ARG_NONE,   0, NA_T },
+    { /* BINSEP */      docmd_binsep,      "BINSEP",              0x00, 0x00, 0xa7, 0x3b,  6, ARG_NONE,   0, NA_T },
+    { /* OCTSEP */      docmd_octsep,      "OCTSEP",              0x00, 0x00, 0xa7, 0x3c,  6, ARG_NONE,   0, NA_T },
+    { /* DECSEP */      docmd_decsep,      "DECSEP",              0x00, 0x00, 0xa7, 0x3d,  6, ARG_NONE,   0, NA_T },
+    { /* HEXSEP */      docmd_hexsep,      "HEXSEP",              0x00, 0x00, 0xa7, 0x3e,  6, ARG_NONE,   0, NA_T },
+
     /* Useful X-Fcn functions missing from the 42S */
     { /* ANUM */        docmd_anum,        "ANUM",                0x00, 0x00, 0xa6, 0x42,  4, ARG_NONE,   0, NA_T },
     { /* X<>F */        docmd_x_swap_f,    "X<>F",                0x00, 0x00, 0xa6, 0x6e,  4, ARG_NONE,   1, 0x01 },
@@ -454,6 +498,8 @@ const command_spec cmd_array[] =
     { /* PCOMPLX */     docmd_pcomplx,     "PC\317\315P\314X",    0x00, 0x00, 0xa7, 0xf9,  7, ARG_NONE,  -1, 0x00 },
     { /* CAPS */        docmd_caps,        "CAPS",                0x42, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
     { /* MIXED */       docmd_mixed,       "Mixed",               0x42, 0x00, 0x00, 0x00,  5, ARG_NONE,   0, NA_T },
+    { /* STATIC */      docmd_static,      "STAT\311\303",        0x42, 0x00, 0x00, 0x00,  6, ARG_NONE,   0, NA_T },
+    { /* DYNAMIC */     docmd_dynamic,     "DYN\301\315\311\303", 0x42, 0x00, 0x00, 0x00,  7, ARG_NONE,   0, NA_T },
     { /* SKIP */        docmd_skip,        "SKIP",                0x00, 0x00, 0xa2, 0x74,  4, ARG_NONE,   0, NA_T },
     { /* CPXMAT_T */    docmd_cpxmat_t,    "C\320\330M\301T?",    0x00, 0x00, 0xa2, 0x75,  7, ARG_NONE,   1, ALLT },
     { /* TYPE_T */      docmd_type_t,      "TYP\305?",            0x00, 0x00, 0xa2, 0x76,  5, ARG_NONE,   1, ALLT },
