@@ -373,112 +373,157 @@
 #define CMD_LSTO        331
 #define CMD_SST_UP      332
 #define CMD_SST_RT      333
-#define CMD_WSIZE       334
-#define CMD_WSIZE_T     335
-#define CMD_YMD         336
-#define CMD_BSIGNED     337
-#define CMD_BWRAP       338
-#define CMD_BRESET      339
-#define CMD_GETKEY1     340
-#define CMD_GETKEYA     341
-#define CMD_LASTO       342
-#define CMD_LCLV        343
+#define CMD_YMD         334
+#define CMD_GETKEY1     335
+#define CMD_GETKEYA     336
+#define CMD_LASTO       337
+#define CMD_LCLV        338
+/* BASE enhancements */
+#define CMD_SL          339
+#define CMD_SR          340
+#define CMD_ASR         341
+#define CMD_SLN         342
+#define CMD_SRN         343
+#define CMD_ASRN        344
+#define CMD_LJ          345
+#define CMD_RJ          346
+#define CMD_RL          347
+#define CMD_RR          348
+#define CMD_RLC         349
+#define CMD_RRC         350
+#define CMD_RLN         351
+#define CMD_RRN         352
+#define CMD_RLCN        353
+#define CMD_RRCN        354
+#define CMD_SB          355
+#define CMD_CB          356
+#define CMD_B_T         357
+#define CMD_NUM_B       358
+#define CMD_MASKL       359
+#define CMD_MASKR       360
+#define CMD_SC          361
+#define CMD_CC          362
+#define CMD_C_T         363
+#define CMD_N_TO_BS     364
+#define CMD_N_TO_BD     365
+#define CMD_N_TO_BQ     366
+#define CMD_N_TO_DS     367
+#define CMD_N_TO_DD     368
+#define CMD_N_TO_DQ     369
+#define CMD_BS_TO_N     370
+#define CMD_BD_TO_N     371
+#define CMD_BQ_TO_N     372
+#define CMD_DS_TO_N     373
+#define CMD_DD_TO_N     374
+#define CMD_DQ_TO_N     375
+#define CMD_WSIZE       376
+#define CMD_WSIZE_T     377
+#define CMD_BSIGNED     378
+#define CMD_BWRAP       379
+#define CMD_BRESET      380
+#define CMD_DECINT      381
+#define CMD_BINSEP      382
+#define CMD_OCTSEP      383
+#define CMD_DECSEP      384
+#define CMD_HEXSEP      385
 /* Useful X-Fcn functions missing from the 42S */
-#define CMD_ANUM        344
-#define CMD_X_SWAP_F    345
-#define CMD_RCLFLAG     346
-#define CMD_STOFLAG     347
+#define CMD_ANUM        386
+#define CMD_X_SWAP_F    387
+#define CMD_RCLFLAG     388
+#define CMD_STOFLAG     389
 /* User-defined functions */
-#define CMD_FUNC        348
-#define CMD_ERRMSG      349
-#define CMD_ERRNO       350
-#define CMD_RTNYES      351
-#define CMD_RTNNO       352
-#define CMD_RTNERR      353
-#define CMD_STRACE      354
+#define CMD_FUNC        390
+#define CMD_ERRMSG      391
+#define CMD_ERRNO       392
+#define CMD_RTNYES      393
+#define CMD_RTNNO       394
+#define CMD_RTNERR      395
+#define CMD_STRACE      396
 /* Big Stack */
-#define CMD_4STK        355
-#define CMD_L4STK       356
-#define CMD_NSTK        357
-#define CMD_LNSTK       358
-#define CMD_DEPTH       359
-#define CMD_DROP        360
-#define CMD_DROPN       361
-#define CMD_DUP         362
-#define CMD_DUPN        363
-#define CMD_PICK        364
-#define CMD_UNPICK      365
-#define CMD_RDNN        366
-#define CMD_RUPN        367
+#define CMD_4STK        397
+#define CMD_L4STK       398
+#define CMD_NSTK        399
+#define CMD_LNSTK       400
+#define CMD_DEPTH       401
+#define CMD_DROP        402
+#define CMD_DROPN       403
+#define CMD_DUP         404
+#define CMD_DUPN        405
+#define CMD_PICK        406
+#define CMD_UNPICK      407
+#define CMD_RDNN        408
+#define CMD_RUPN        409
 /* Miscellaneous */
-#define CMD_NOP         368
-#define CMD_FMA         369
-#define CMD_PGMMENU     370
-#define CMD_PMEXEC      371
-#define CMD_PGMVAR      372
-#define CMD_VARMNU1     373
-#define CMD_X2LINE      374
-#define CMD_A2LINE      375
-#define CMD_A2PLINE     376
-#define CMD_RCOMPLX     377
-#define CMD_PCOMPLX     378
-#define CMD_CAPS        379
-#define CMD_MIXED       380
-#define CMD_SKIP        381
-#define CMD_CPXMAT_T    382
-#define CMD_TYPE_T      383
-#define CMD_A_THRU_F_2  384
-#define CMD_DROP_CANCL  385
-#define CMD_PRREG       386
-#define CMD_CSLD_T      387
-#define CMD_C_LN_1_X    388
-#define CMD_C_E_POW_X_1 389
-#define CMD_GETMI       390
-#define CMD_PUTMI       391
-#define CMD_GETLI       392
-#define CMD_PUTLI       393
-#define CMD_LOCK        394
-#define CMD_UNLOCK      395
-#define CMD_IDENT       396
+#define CMD_NOP         410
+#define CMD_FMA         411
+#define CMD_PGMMENU     412
+#define CMD_PMEXEC      413
+#define CMD_PGMVAR      414
+#define CMD_VARMNU1     415
+#define CMD_X2LINE      416
+#define CMD_A2LINE      417
+#define CMD_A2PLINE     418
+#define CMD_RCOMPLX     419
+#define CMD_PCOMPLX     420
+#define CMD_CAPS        421
+#define CMD_MIXED       422
+#define CMD_STATIC      423
+#define CMD_DYNAMIC     424
+#define CMD_SKIP        425
+#define CMD_CPXMAT_T    426
+#define CMD_TYPE_T      427
+#define CMD_A_THRU_F_2  428
+#define CMD_DROP_CANCL  429
+#define CMD_PRREG       430
+#define CMD_CSLD_T      431
+#define CMD_C_LN_1_X    432
+#define CMD_C_E_POW_X_1 433
+#define CMD_GETMI       434
+#define CMD_PUTMI       435
+#define CMD_GETLI       436
+#define CMD_PUTLI       437
+#define CMD_LOCK        438
+#define CMD_UNLOCK      439
+#define CMD_IDENT       440
 /* String & List Functions */
-#define CMD_XSTR        397
-#define CMD_XASTO       398
-#define CMD_LXASTO      399
-#define CMD_XVIEW       400
-#define CMD_APPEND      401
-#define CMD_EXTEND      402
-#define CMD_SUBSTR      403
-#define CMD_LENGTH      404
-#define CMD_HEAD        405
-#define CMD_REV         406
-#define CMD_POS         407
-#define CMD_S_TO_N      408
-#define CMD_N_TO_S      409
-#define CMD_NN_TO_S     410
-#define CMD_C_TO_N      411
-#define CMD_N_TO_C      412
-#define CMD_LIST_T      413
-#define CMD_NEWLIST     414
-#define CMD_TO_LIST     415
-#define CMD_FROM_LIST   416
+#define CMD_XSTR        441
+#define CMD_XASTO       442
+#define CMD_LXASTO      443
+#define CMD_XVIEW       444
+#define CMD_APPEND      445
+#define CMD_EXTEND      446
+#define CMD_SUBSTR      447
+#define CMD_LENGTH      448
+#define CMD_HEAD        449
+#define CMD_REV         450
+#define CMD_POS         451
+#define CMD_S_TO_N      452
+#define CMD_N_TO_S      453
+#define CMD_NN_TO_S     454
+#define CMD_C_TO_N      455
+#define CMD_N_TO_C      456
+#define CMD_LIST_T      457
+#define CMD_NEWLIST     458
+#define CMD_TO_LIST     459
+#define CMD_FROM_LIST   460
 /* Generalized Comparisons */
-#define CMD_X_EQ_NN     417
-#define CMD_X_NE_NN     418
-#define CMD_X_LT_NN     419
-#define CMD_X_GT_NN     420
-#define CMD_X_LE_NN     421
-#define CMD_X_GE_NN     422
-#define CMD_0_EQ_NN     423
-#define CMD_0_NE_NN     424
-#define CMD_0_LT_NN     425
-#define CMD_0_GT_NN     426
-#define CMD_0_LE_NN     427
-#define CMD_0_GE_NN     428
+#define CMD_X_EQ_NN     461
+#define CMD_X_NE_NN     462
+#define CMD_X_LT_NN     463
+#define CMD_X_GT_NN     464
+#define CMD_X_LE_NN     465
+#define CMD_X_GE_NN     466
+#define CMD_0_EQ_NN     467
+#define CMD_0_NE_NN     468
+#define CMD_0_LT_NN     469
+#define CMD_0_GT_NN     470
+#define CMD_0_LE_NN     471
+#define CMD_0_GE_NN     472
 /* For Plus42 compatibility */
-#define CMD_WIDTH       429
-#define CMD_HEIGHT      430
+#define CMD_WIDTH       473
+#define CMD_HEIGHT      474
 
-#define CMD_SENTINEL    431
+#define CMD_SENTINEL    475
 
 
 /* command_spec.argtype */
